Module field

Module field 

Model and field definitions parsed from the CLI (name:String email:String ...).

Structs

Field
A single field of a model: name:Type.
ModelSpec
A model: a name plus its fields, as produced by gize make model Name f:T ....

Enums

FieldType
The set of scalar field types Gize understands in the MVP.